## 3.5.0.20240205 (2024-02-05)

A new shade of Black (#11362)

## 3.5.0.20240106 (2024-01-06)

Update typing_extensions imports in third-party stubs (#11245)

## 3.5.0.11 (2023-11-22)

third-party stubs: Add several missing `__del__` methods (#11054)

## 3.5.0.10 (2023-09-01)

`_CField` as a generic descriptor protocol (#10595)

## 3.5.0.9 (2023-07-20)

Add an upstream_repository field to METADATA.toml (#10487)

Closes: #10478

## 3.5.0.8 (2023-03-27)

Add default values for third-party stubs beginning with 'P' (#9957)

## 3.5.0.7 (2023-03-09)

pyserial: Fix read and write methods (#9825)

## 3.5.0.6 (2023-02-26)

Improve many `__(a)exit__` annotations (#9696)

## 3.5.0.5 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 3.5.0.4 (2023-02-19)

`pyserial`: fix stubtest errors (#9722)

## 3.5.0.3 (2023-02-15)

Use `typing_extensions.Self` instead of `_typeshed.Self` (#9702)

## 3.5.0.2 (2023-02-09)

Enable stubtest for `pyserial` (#9692)

## 3.5.0.1 (2023-02-02)

Fix optional USB attributes in pyserial's `ListPortInfo` (#9654)

Some USB specific attributes in pyserial's [`serial.tools.list_port_common.ListPortInfo`](https://github.com/python/typeshed/blob/main/stubs/pyserial/serial/tools/list_ports_common.pyi#L11-L24) class are not always available. They depend on the USB device and its driver correctly reporting these attributes. I discovered this recently with a new device that does not report its serial number. Only the Vendor ID `vid` and Product ID `pid` are guaranteed (This can be seen [here](https://github.com/pyserial/pyserial/blob/master/serial/tools/list_ports_linux.py#L52-L62) where `vid` and `pid` are always cast as `int` while other attributes are left as `str | None` for USB devices).
This is a follow up to #9347 and the discussion at https://github.com/python/typeshed/pull/9347#issuecomment-1358245865

## 3.5.0.0 (2022-12-22)

Add stubs for the pyserial package (#9347)

